==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/html.knockout/test/unit/src/org/netbeans/modules/html/knockout/KOHtmlExtensionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.html.knockout;

import javax.swing.text.BadLocationException;
import org.netbeans.junit.AssertionFailedErrorException;
import org.netbeans.modules.csl.api.test.CslTestBase;
import org.netbeans.modules.csl.spi.DefaultLanguageConfig;
import org.netbeans.modules.html.editor.completion.HtmlCompletionTestSupport;
import org.netbeans.modules.html.editor.completion.HtmlCompletionTestSupport.Match;
import org.netbeans.modules.html.editor.gsf.HtmlLanguage;
import org.netbeans.modules.parsing.spi.ParseException;

/**
 *
 * @author marekfukala
 */
public class KOHtmlExtensionTest extends CslTestBase {
    
    public KOHtmlExtensionTest(String name) {
        super(name);
    }

    @Override
    protected String getPreferredMimeType() {
        return "text/html";
    }

    @Override
    protected DefaultLanguageConfig getPreferredLanguage() {
        return new HtmlLanguage();
    }
    
    public void testCompletionWithPrefix() {
        assertCC("<div data-bind=\"t|", Match.EXACT, "text", "template");
        assertCC("<div data-bind=\"tex|", Match.EXACT, "text");
        assertCC("<div data-bind=\"text|", Match.EXACT, "text");
        assertCC("<div data-bind=\"text|:value", Match.EXACT, "text");
        assertCC("<div data-bind=\"text:value, v|", Match.EXACT, "visible", "value");
    }
    
    public void testCompletionWithoutPrefix() {
        assertCC("<div data-bind=\"|", Match.CONTAINS, "text");
        assertCC("<div data-bind=\"  |", Match.CONTAINS, "text");
        assertCC("<div data-bind=\"text:value,|", Match.CONTAINS, "text");
        assertCC("<div data-bind=\"text:value, |", Match.CONTAINS, "text");
    }
    
    private void assertCC(String documentText, Match type, String... expectedItemsNames)  {
        try {
            HtmlCompletionTestSupport.assertItems(getDocument(documentText), expectedItemsNames, type, -1);
        } catch (BadLocationException | ParseException ex) {
            throw new AssertionFailedErrorException(ex);
        }
    }
    
}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/html.knockout/test/unit/src/org/netbeans/modules/html/knockout/KOHtmlExtensionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.html.knockout;

import javax.swing.text.BadLocationException;
import org.netbeans.junit.AssertionFailedErrorException;
import org.netbeans.modules.csl.api.test.CslTestBase;
import org.netbeans.modules.csl.spi.DefaultLanguageConfig;
import org.netbeans.modules.html.editor.completion.HtmlCompletionTestSupport;
import org.netbeans.modules.html.editor.completion.HtmlCompletionTestSupport.Match;
import org.netbeans.modules.html.editor.gsf.HtmlLanguage;
import org.netbeans.modules.parsing.spi.ParseException;

/**
 *
 * @author marekfukala
 */
public class KOHtmlExtensionTest extends CslTestBase {
    
    public KOHtmlExtensionTest(String name) {
        super(name);
    }

    @Override
    protected String getPreferredMimeType() {
        return "text/html";
    }

    @Override
    protected DefaultLanguageConfig getPreferredLanguage() {
        return new HtmlLanguage();
    }
    
    public void testCompletionWithPrefix() {
        assertCC("<div data-bind=\"t|", Match.EXACT, "text", "textInput", "template");
        assertCC("<div data-bind=\"tex|", Match.EXACT, "text", "textInput");
        assertCC("<div data-bind=\"text|", Match.EXACT, "text", "textInput");
        assertCC("<div data-bind=\"text|:value", Match.EXACT, "text", "textInput");
        assertCC("<div data-bind=\"text:value, v|", Match.EXACT, "visible", "value");
    }
    
    public void testCompletionWithoutPrefix() {
        assertCC("<div data-bind=\"|", Match.CONTAINS, "text");
        assertCC("<div data-bind=\"  |", Match.CONTAINS, "text");
        assertCC("<div data-bind=\"text:value,|", Match.CONTAINS, "text");
        assertCC("<div data-bind=\"text:value, |", Match.CONTAINS, "text");
    }
    
    private void assertCC(String documentText, Match type, String... expectedItemsNames)  {
        try {
            HtmlCompletionTestSupport.assertItems(getDocument(documentText), expectedItemsNames, type, -1);
        } catch (BadLocationException | ParseException ex) {
            throw new AssertionFailedErrorException(ex);
        }
    }
    
}
